@@ -36,6 +36,23 @@ class line_bulk(libgpiodcxx.line_bulk):
     pass
 
 
+def find_line(name: str) -> line:
+    """
+    @brief Find a GPIO line by name. Search all GPIO chips present on the
+           system.
+
+    @param name: Name of the line.
+
+    @return A line object - empty if the line was not found.
+    """
+    for c in chip_iter():
+        ret = c.find_line(name)
+        if bool(ret):
+            return ret
+
+    return ret
+
+
 class line_event(libgpiodcxx.line_event):
     # pylint: disable=too-few-public-methods
     pass
@@ -44,3 +61,27 @@ class line_event(libgpiodcxx.line_event):
 class line_request(libgpiodcxx.line_request):
     # pylint: disable=too-few-public-methods
     pass
+
+
+class chip_iter(libgpiodcxx.chip_iter):
+    # pylint: disable=too-few-public-methods
+    pass
+
+
+def make_chip_iter() -> chip_iter:
+    """
+    @brief Create a new chip_iter.
+
+    @return New chip iterator object pointing to the first GPIO chip on the
+            system.
+
+    Usage:
+        for c in make_chip_iter():
+            print(c.label)
+    """
+    return chip_iter().__iter__()
+
+
+class line_iter(libgpiodcxx.line_iter):
+    # pylint: disable=too-few-public-methods
+    pass
